==> cBioPortalData_2.4.10.zip: cBioPortalData/doc/cBioPortalDataErrors.R <==
## ---- setup, include=FALSE----------------------------------------------------
knitr::opts_chunk$set(cache = TRUE)

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(cBioPortalData)
library(AnVIL)

## -----------------------------------------------------------------------------
api_errs <- system.file(
    "extdata", "err_api_info.rda", package = "cBioPortalData", mustWork = TRUE
)
load(api_errs)
err_api_info

## -----------------------------------------------------------------------------
class(err_api_info)
length(err_api_info)
lengths(err_api_info)

## -----------------------------------------------------------------------------
names(err_api_info)

## -----------------------------------------------------------------------------
err_api_info[['Inconsistent build numbers found']]

## -----------------------------------------------------------------------------
err_api_info

## -----------------------------------------------------------------------------
pack_errs <- system.file(
    "extdata", "err_pack_info.rda", package = "cBioPortalData", mustWork = TRUE
)
load(pack_errs)
err_pack_info

## -----------------------------------------------------------------------------
length(err_pack_info)
lengths(err_pack_info)

## -----------------------------------------------------------------------------
names(err_pack_info)

## -----------------------------------------------------------------------------
err_pack_info

## -----------------------------------------------------------------------------
sessionInfo()

==> cBioPortalData_2.6.1.zip: cBioPortalData/doc/cBioPortalDataErrors.R <==
## ---- setup, include=FALSE----------------------------------------------------
knitr::opts_chunk$set(cache = TRUE)

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(cBioPortalData)
library(AnVIL)

## -----------------------------------------------------------------------------
api_errs <- system.file(
    "extdata", "api", "err_api_info.rda",
    package = "cBioPortalData", mustWork = TRUE
)
load(api_errs)

## -----------------------------------------------------------------------------
class(err_api_info)
length(err_api_info)
lengths(err_api_info)

## -----------------------------------------------------------------------------
names(err_api_info)

## -----------------------------------------------------------------------------
err_api_info[['Inconsistent build numbers found']]

## -----------------------------------------------------------------------------
err_api_info

## -----------------------------------------------------------------------------
pack_errs <- system.file(
    "extdata", "pack", "err_pack_info.rda",
    package = "cBioPortalData", mustWork = TRUE
)
load(pack_errs)

## -----------------------------------------------------------------------------
length(err_pack_info)
lengths(err_pack_info)

## -----------------------------------------------------------------------------
names(err_pack_info)

## -----------------------------------------------------------------------------
err_pack_info

## -----------------------------------------------------------------------------
sessionInfo()
